=============
API Reference
=============

API reference for ``public``:


.. autofunction:: public.public

.. autofunction:: public.private

.. autofunction:: public.install


Types:

.. autoclass:: public.ModuleAware
   :members:
